@@ -6,7 +6,7 @@ use Config;
 use Fatal qw(open);
 
 our @EXPORT_OK = qw(awx_arch_file awx_install_arch_file
-                    awx_install_arch_auto_file awx_patch
+                    awx_install_arch_auto_file
                     awx_arch_dir awx_install_arch_dir);
 
 sub awx_arch_file {
@@ -39,25 +39,4 @@ sub awx_install_arch_auto_file {
                          File::Spec->splitdir( $dir ), $file );
 }
 
-sub awx_patch {
-    my( $file, $patch, $out ) = @_;
-    require Text::Patch;
-    local $/;
-    my $fh;
-
-    open $fh, '<', $file;
-    my $file_c = readline $fh;
-    close $fh;
-
-    open $fh, '<', $patch;
-    my $patch_c = readline $fh;
-    close $fh;
-
-    my $out_c = Text::Patch::patch( $file_c, $patch_c, STYLE => 'Unified' );
-
-    open $fh, '>', $out;
-    print $fh, $out_c;
-    close $fh;
-}
-
 1;
